



if not exist %PREFIX%\Library\bin\libmatio.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\Library\lib\libmatio.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\Library\include\matio.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
